
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.23.13',
    'branch_nick': 'release-1.23-LTS',
    'revision_id': '2bcf613c4401bb267a426764a5bb67dcf74a4d88',
    'revno': 10102
}
